==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GetVirtualRouterPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GetVirtualRouterPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getVirtualRouter.
 * @property meshName Name of the mesh in which the virtual router exists
 * @property meshOwner
 * @property name Name of the virtual router.
 * @property tags Map of tags.
 */
public data class GetVirtualRouterPlainArgs(
    public val meshName: String,
    public val meshOwner: String? = null,
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GetVirtualRouterPlainArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GetVirtualRouterPlainArgs =
        com.pulumi.aws.appmesh.inputs.GetVirtualRouterPlainArgs.builder()
            .meshName(meshName.let({ args0 -> args0 }))
            .meshOwner(meshOwner?.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetVirtualRouterPlainArgs].
 */
@PulumiTagMarker
public class GetVirtualRouterPlainArgsBuilder internal constructor() {
    private var meshName: String? = null

    private var meshOwner: String? = null

    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the mesh in which the virtual router exists
     */
    @JvmName("ykgmetbaykomvcet")
    public suspend fun meshName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.meshName = mapped
    }

    /**
     * @param value
     */
    @JvmName("bxspvmcteqbejnmd")
    public suspend fun meshOwner(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.meshOwner = mapped
    }

    /**
     * @param value Name of the virtual router.
     */
    @JvmName("exodfujycoudhmcp")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags.
     */
    @JvmName("rjofhabhiakubmkq")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags.
     */
    @JvmName("alpdqlopbmyrtumo")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetVirtualRouterPlainArgs = GetVirtualRouterPlainArgs(
        meshName = meshName ?: throw PulumiNullFieldException("meshName"),
        meshOwner = meshOwner,
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/GetVirtualRouterPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.GetVirtualRouterPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * A collection of arguments for invoking getVirtualRouter.
 * @property meshName Name of the mesh in which the virtual router exists
 * @property meshOwner
 * @property name Name of the virtual router.
 * @property tags Map of tags.
 */
public data class GetVirtualRouterPlainArgs(
    public val meshName: String,
    public val meshOwner: String? = null,
    public val name: String,
    public val tags: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.GetVirtualRouterPlainArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.GetVirtualRouterPlainArgs =
        com.pulumi.aws.appmesh.inputs.GetVirtualRouterPlainArgs.builder()
            .meshName(meshName.let({ args0 -> args0 }))
            .meshOwner(meshOwner?.let({ args0 -> args0 }))
            .name(name.let({ args0 -> args0 }))
            .tags(tags?.let({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() })).build()
}

/**
 * Builder for [GetVirtualRouterPlainArgs].
 */
@PulumiTagMarker
public class GetVirtualRouterPlainArgsBuilder internal constructor() {
    private var meshName: String? = null

    private var meshOwner: String? = null

    private var name: String? = null

    private var tags: Map<String, String>? = null

    /**
     * @param value Name of the mesh in which the virtual router exists
     */
    @JvmName("vufnmqglfenflebr")
    public suspend fun meshName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.meshName = mapped
    }

    /**
     * @param value
     */
    @JvmName("bauqnbecknqicjiw")
    public suspend fun meshOwner(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.meshOwner = mapped
    }

    /**
     * @param value Name of the virtual router.
     */
    @JvmName("qpbrlrlasuqrrvbn")
    public suspend fun name(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.name = mapped
    }

    /**
     * @param value Map of tags.
     */
    @JvmName("fwmsnveppsyylebo")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.tags = mapped
    }

    /**
     * @param values Map of tags.
     */
    @JvmName("iftjxltcxttutgck")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.tags = mapped
    }

    internal fun build(): GetVirtualRouterPlainArgs = GetVirtualRouterPlainArgs(
        meshName = meshName ?: throw PulumiNullFieldException("meshName"),
        meshOwner = meshOwner,
        name = name ?: throw PulumiNullFieldException("name"),
        tags = tags,
    )
}
